define array_flatten(arr)
%!%+
%\function{array_flatten}
%\synopsis{flattens an array of Array_Type[] into a single array}
%\usage{Any_Type array_flatten(Array_Type[] array);}
%\description
%    The given 'array' itself contains arrays of any
%    data type. This function flattens the 'array'
%    such that all internal arrays are merged.
%
%    Also the array can have entries of any data type,
%    they must be of the same type! Otherwise the function
%    will throw an error.
%    To avoid this split the array, e.g., with
%
%       arr1 = arr[where(_typeof(arr)==Double_Type)];
%
%    or if there are NULL entries,
%
%       arr1 = arr[wherenot( arr == NULL )];
%
%   and use arr1 as argument for array_flatten!
%    
%\example
%    variable arr = Array_Type[3];
%    arr[0] = [1,2,3,4];
%    arr[1] = [5,6];
%    arr[2] = [7,8,9];
%    
%    variable arrF = array_flatten(arr);
%    % returns an Integer_Type[9] containing
%    % [1,2,3,4,5,6,7,8,9]
%!%-
{
  % In principle this function would look like:
  %    return [__push_array(arr[wherenot(arr))])];
  % However, the stack is limited to ~2000 elements!
  % Therefore a split is neccessary. Note that this method here is
  % MUCH MUCH faster then just using a loop over all entries, as e.g.
  % foreach e (arr) ret = [ret, e];

  
  variable len = length(arr);
  variable stacklimit = 2000; 
  variable af = [ __push_array( arr[[0:(len<stacklimit?len:stacklimit)-1]] ) ];
  
  variable left = len-stacklimit;
  variable i;
  _for i ( 1, len/stacklimit ){
    af = [ af, __push_array( arr[ i*stacklimit+ [0:(left<stacklimit?left:stacklimit)-1] ] ) ];
    left -= stacklimit;
  }
  
  return af; 
}
