
private define call_func_with_qualifiers ()
{
  variable q = ();
  variable args = __pop_list (_NARGS-2);
  variable f = ();
  
  return (@f)(__push_list(args) ;; q);
}

define array_map_qualifiers()
%!%+
%\function{array_map_qualifiers}
%\synopsis{Apply a function to each element of an array (also if given as qualifier)}
%\usage{Array_Type array_map (DataType_Type type, Ref_Type func, args, ... );}
%\altusage{(Array_Type, ...) array_map (DataType_Type type, ..., Ref_Type func, args, ... );}
%\description
%   The 'array_map_qualifiers' function is an extension of the 'array_map'
%   function and supports all its features.
%   This function also works for qualifiers! First of all qualifiers given to
%   the 'array_map_qualifiers' are passed onto the called function 'func'.
%
%   Furthermore if the qualifier(s) itself is an array, it will be mapped too!
%   This is especially helpfull when used for calls of integration function
%   such as 'qromb' as these require parameters to be given as qualifiers!
%
%   This functionality can be turned off with the "noqualmap"
%   qualifier, which is necessary for, e.g., epochfolding routines (and much
%   faster!)
%
%   NOTE that this function works as 'array_map', i.e., the mapping will apply
%   for the first argument which is an array! As the qualifiers are passed after
%   the arguments, an argument array will supersede a qualifier array as long as
%   they do not have the same length.
%
%\example
%   define t(x){ return qualifier("a",0)*x;};
%
%   %% Mapping function using an argument array:
%     print(array_map_qualifiers( Double_Type, &t, [1,2,3,4] ; a=1 ));
%
%   %% Mapping function using a qualifier array:
%     print(array_map_qualifiers( Double_Type, &t, 1 ; a=[1,2,3,4] ));
%
%   %% Mapping function argument array superseding qualifier array:
%     print(array_map_qualifiers( Double_Type, &t, [3,4,5,6] ; a=[1,2] ));
%     
%   %% Mapping function using argument array AND qualifier array:
%     print(array_map_qualifiers( Double_Type, &t, [3,4,5,6] ; a=[1,2,3,4] ));
%
%   %% Map function using a qualifier array application on 'qromb' integrater
%     print(array_map_qualifiers( Double_Type, &qromb, &t, 0, 1 ; a=[0:2] ));
%
%\seealso{array_map, struct_of_arrays_2_struct_array}
%!%-
{
   variable q  ;
   if (qualifier_exists("noqualmap"))
     {
	q= __qualifiers ();
     }
   else
     {
	q= struct_of_arrays_2_struct_array(__qualifiers ());
     }

   variable args = __pop_list (_NARGS-1);
   variable ret = ();
  
   return array_map (ret, &call_func_with_qualifiers,
		    __push_list (args), q);
}
