%%%%%%%%%%%%%%%%%%%%%
define array_zip()
%%%%%%%%%%%%%%%%%%%%%
%!%+
%\function{array_zip}
%\synopsis{"zip" two or more arrays together}
%\usage{Any_Type array_zip(Any_Type[] a, b, ...);}
%\description
%    Returns an array of tuples (or higher orders), where each tuple i
%    contains the i-th element from each of the given arrays. The
%    returned array is truncated to the length of the shortest
%    array. Thus, the number of tuples is equal to this smallest
%    length.
%\example
%    a = [1:10];
%    b = [11:20];
%    c = array_zip(a,b);
%    % c = [1,11,2,12,3,13,4,14,...,10,20];
%!%-
{
  % put all arrays into an Array_Type[] array
  variable arr = __pop_args(_NARGS);
  arr = array_struct_field(arr, "value");
  % get shortest length among all arrays
  variable l = min(array_map(Integer_Type, &length, arr));
  % defined index array
  variable idx = [:l-1];
  % truncate and merge all arrays
  variable merge = (_typeof(arr[0]))[_NARGS*l];
  variable i;
  _for i (0, _NARGS-1, 1) {
    % indices where to put the current array into the merged one
    idx = [i::_NARGS];
    % add array to merge
    merge[idx] = arr[i];
  }
  return merge;
}
