%%%%%%%%%%%%%%%%%%%%%%%%%%
define blocks_between_gaps()
%%%%%%%%%%%%%%%%%%%%%%%%%%
%!%+
%\function{blocks_between_gaps}
%\synopsis{retrieves blocks in an array whose elements may contain gaps}
%\usage{Integer_Type blocks[] = blocks_between_gaps(Double_Type a[], Double_Type gap);}
%\description
%    The array a has to contain monotonically increasing values.
%    The return value will be an integer array of the same length,
%    whose elements start with 0 and increase by 1 whenever the difference
%    of sequential elements of the array a is larger than gap.
%\seealso{split_struct, split_lc_at_gaps}
%!%-
{
  variable a, gap;
  switch(_NARGS)
  { case 2: (a, gap) = (); }
  { help(_function_name); return; }

  variable i, blocks = Integer_Type[length(a)];
  blocks[0] = 0;
  _for i (1, length(a)-1, 1)
  { blocks[i] = blocks[i-1];
    if(a[i]-a[i-1]>gap)  blocks[i]++;
  }
  return blocks;
}
