define get_par_combinations()
%!%+
%\function{get_par_combinations}
%\synopsis{calculates all possible parameter combinations}
%\usage{Struct_Type[] parcomb = get_par_combinations( Struct_Type par )}
%\description
%   All possible parameter combinations are calculated for the
%   given parameter structure. That means if there are multiple
%   parameters, each with there own grid all possible combinations
%   are returned.
%
%   'par' must be a Struct_Type, but there are no restriction
%   otherwise. Each field is representing a parameter and its
%   value its grid, which can be any Data_Type (e.g., Double_Type
%   or String_Type)!
%
%   NOTE that the combination is done, s.t. the last parameter
%   in the struct is varied first and the first parameter last,
%   i.e., the first parameter in the parameter combination
%   will stay constant longest!
%
%\examples
%   variable par = struct{ a = [0:1:#3],
%                          b = ["hello","world"],
%                          c = [ 2001, 2012]
%                        };
%   variable parcomb = get_par_combinations( par );
%   print(parcomb);
%!%-
{
  variable par;
  switch(_NARGS)
  { case 1 : par = (); }
  { help(_function_name()); return; }
  
  %% get the names of the parameters
  variable parnames = get_struct_field_names( par );
  
  % get the length of each individual 'par' range
  variable Ni = array_map( Integer_Type, &length, array_map( Array_Type, &get_struct_field, par, parnames ));
  % number of all possible combinations
  variable N = nint(prod(Ni));
  
  % initialize parcom struct array:
  variable parcomb = @Struct_Type(parnames);
  % NOTE: It was parcomb = struct_array( N, @Struct_Type(parnames) )
  %       which is a memery eater !!!!
  
  variable ii;
  _for ii ( 0, length(Ni)-1 ){ % loop all parameters and set their values
    set_struct_field(parcomb, parnames[ii], _typeof( get_struct_field(par,parnames[ii]) )[N] );
  }
  
  variable nn, ind;
  _for nn ( 0, N-1 ){ % loog all possible combinations
    _for ii ( 0, length(Ni)-1 ){ % loop all parameters and set their values
      ind = ( nn / nint(prod( Ni[[ii+1:length(Ni)-1]] )) ) mod Ni[ii];
      get_struct_field( parcomb, parnames[ii] )[nn] = [get_struct_field( par, parnames[ii] )][ind];
    }
  }
  
  return parcomb;
}
