%%%%%%%%%%%%%%
define min_max()
%%%%%%%%%%%%%%
%!%+
%\function{min_max}
%\synopsis{returns the minimum and maximum value of an array}
%\usage{(mn, mx) = min_max(Double_Type a[]);
%\altusage{(mn, mx) = min_max(Double_Type a1[], a2[], ...);}
%}
%\qualifiers{
%\qualifier{pad}{[=0] additive fraction to be padded on both sides:\n
%                   \code{-dmin = dmax = (max-min) * pad}\n
%                This qualifier may be overwritten by the following ones:}
%\qualifier{dmin}{[=0] difference added to the minimum}
%\qualifier{dmax}{[=0] difference added to the maximum}
%
%\qualifier{logpad}{[=0] multiplicative fraction to be padded on both sides:\n
%                      \code{fmin^-1 = fmax = (max/min)^logpad}\n
%                   All array elements must be either positive or negative.
%                   (For negative arrays \code{-A},  \code{[min_max(-A; logpad=lp)]}
%                    is the same as  \code{array_reverse([min_max(A; logpad=lp))} .)
%                   This qualifier may be overwritten by the following ones:}
%\qualifier{fmin}{[=1] factor to multiply the minimum}
%\qualifier{fmax}{[=1] factor to multiply the maximum}
%}
%\description
%     \code{mn = min(a) * fmin + dmin;}\n
%     \code{mx = max(a) * fmax + dmax;}
%\seealso{min, max, moment}
%!%-
{
  variable a;
  switch(_NARGS)
  { case 1: a = (); }
  { case 0: help(_function_name); return; }
  { % else:
      a = ();
      loop (_NARGS-1)
      {
	variable arg = ();
	a = [arg, a];
      }
  }
  variable mn = min(a), mx = max(a);
  variable pad = (mx-mn)*qualifier("pad", 0);
  variable logpad = 1;
  if(qualifier_exists("logpad"))
  {
    if(-2 < sign(mn) + sign(mx) < 2)
      throw UsageError, "all array elements must be either positive or negative when using logpad";
    logpad = (1.*mx/mn)^qualifier("logpad", 0);
  }
  return mn * qualifier("fmin", 1/logpad) + qualifier("dmin", -pad),
         mx * qualifier("fmax",   logpad) + qualifier("dmax",  pad);
}
