%%%%%%%%%%%%%%%%%%%%%%%%%%%
define Roche_lobe_dimension()
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%!%+
%\function{Roche_lobe_dimension}
%\synopsis{determines the size of the Roche lobe}
%\usage{Struct_Type Roche_lobe_dimension(Double_Type q)}
%\description
%    The structure has the following fields:\n
%    \code{potential}: the critical Roche potential of the Roche lobe\n
%    {\code{x}/\code{y}/\code{z}}{\code{min}/\code{max}}: the coordinates of the envelopping box
%!%-
{
  variable q;
  switch(_NARGS)
  { case 1: q = (); }
  { help(_function_name()); return; }

  variable eps = 1e-8;
  variable qualifiers = struct { q = q };  % __qualifiers();
  variable xmax = find_function_maximum(&Roche_potential, eps, 1.-eps; qualifiers=qualifiers);
  variable phi = Roche_potential(xmax;; qualifiers);
  variable xmin = find_function_value(&Roche_potential, phi, -xmax, -eps; qualifiers=qualifiers);
  variable ymax = find_multiargumentfunction_value(&Roche_potential, phi, 0, [eps, xmax]; qualifiers=qualifiers);
  variable zmax = find_multiargumentfunction_value(&Roche_potential, phi, 0, 0, [eps, xmax]; qualifiers=qualifiers);
  return struct {
    potential = phi,
    xmin =  xmin,
    xmax =  xmax,
    ymin = -ymax,
    ymax =  ymax,
    zmin = -zmax,
    zmax =  zmax,
  };
}
