define midas_bary_helio_corr()
%!%+
%\function{midas_bary_helio_corr}
%\usage{Struct_Type midas_bary_helio_corr(Y, m, d, H, M, S,  RAh, RAm, RAs,  decdeg, decmin, decsec)}
%\description
%    Y, m, d, H, M, S  specify the date in UT.
%
%    The fields of the returned structure have the following meaning:\n
%     bary_corr_time: Barycentric correction time, in days\n
%    helio_corr_time: Heliocentric correction time, in days\n
%       bary_RV_corr: Total barycentric RV correction, in km/s\n
%      helio_RV_corr: Total heliocentric RV correction, in km/s\n
%    diurnal_RV_corr: (incl.) diurnal RV correction, in km/s
%!%-
{
  variable Y, m, d, H, M, S,  RAh, RAm, RAs,  decdeg, decmin, decsec;
  switch(_NARGS)
  { case 12: (Y, m, d, H, M, S,  RAh, RAm, RAs,  decdeg, decmin, decsec) = ();  }
  { return help(_function_name()); }
  
  variable fp = popen(sprintf("echo 'com/bary %d,%d,%d %d,%d,%f %d,%d,%f %d,%d,%f' | inmidas -p 47", 
			      Y, m, d, H, M, S,  RAh, RAm, RAs,  decdeg, decmin, decsec),
		      "r");
  variable info = struct { 
     bary_corr_time = atof(string_matches(fgetslines(fp, 1)[0], `Barycentric correction time: *\(.*\) day`, 1)[1]),
    helio_corr_time = atof(string_matches(fgetslines(fp, 2)[0], `Heliocentric correction time: *\(.*\) day`, 1)[1]),
       bary_RV_corr = atof(string_matches(fgetslines(fp, 1)[0], `Total barycentric RV correction: *\(.*\) km/s`, 1)[1]),
      helio_RV_corr = atof(string_matches(fgetslines(fp, 1)[0], `Total heliocentric RV correction: *\(.*\) km/s`, 1)[1]),
    diurnal_RV_corr = atof(string_matches(fgetslines(fp, 1)[0], `(incl. diurnal RV correction of *\(.*\) km/s)`, 1)[1]),
  };
  ()=pclose(fp);
  return info;
}
