require("png");

define png_get_colormap_color (colormap, len)
%!%+
%\function{png_get_colormap_color}
%\synopsis{Retrieve a set of colors from a colormap}
%\usage{UInt_Type[] png_get_colormap_color (String_Type map, Int_Type len);}
%\qualifiers{
%  \qualifier{string}{Colors are returned as hex string.}
%}
%\description
%  This function is useful if a range of colors is required.
%  It returns \code{len} values from a linear mapping of the
%  given colormap. \code{len} may at most be 256.
%
%\example
%  variable colors = png_get_colormap_colors("cool", 25);
%  % returns 25 colors from the "cool" map
%  variable colors = png_get_colormap_colors("cool", 25; string);
%  % same, but now as strings
%!%-
{
  if (len > 256)
    throw UsageError, "Can only map into arrays with a length of at most 256 entires.";

  variable map = png_get_colormap(colormap);
  variable colors = UInt_Type[len];

  variable i;
  _for i (0, len-1)
  {
    colors[i] = map[int(round(i*1./(len-1)*255))];
  }

  if (qualifier_exists("string"))
    colors = array_map(String_Type, &sprintf, "%06X", colors);

  return colors;
}
