define rgb2gray()
%!%+
%\function{rgb2gray}
%\synopsis{Weighted RGB to GRAY convertion}
%\usage{Integer_Type gray = rgb2gray( Integer_Type[] RGB );}
%\usage{Integer_Type gray = rgb2gray( Integer_Type[] R, G, B );}
%\description
%    Converts a RGB color, which is either encoded in one Integer or
%    as single channels (R,G,B), into a weighted gray scale using:
%
%    GRAY = (0.3 * R) + (0.59 * G) + (0.11 * B) 
%    
%    The 8 bit gray value(s) are return as
%    Integer_Type[] in the interval [0,255].
%\qualifiers{
%\qualifier{norm}{return values are in Double_Type interval [0,1].}
%\qualifier{rgb}{return values as single RGB encoding:
%                  GRAY << 16 | GRAY << 8 | GRAY}
%}
%
%\seealso{rgb2hsl, hex2rgb}
%!%-
{
  variable R, G, B;
  switch(_NARGS)
  { case 1 : (R, G, B) = rgb2r_g_b(()); }
  { case 3 : (R, G, B) = (); }
  { help(_function_name); };
  
  variable GRAY = nint((0.3 * R) + (0.59 * G) + (0.11 * B));
  
  if( qualifier_exists("norm") ){
    return GRAY/255.;
  }
  if( qualifier_exists("rgb") ){
    return (GRAY << 16 | GRAY << 8 | GRAY);
  }

  return GRAY;
}
