define rgb_interpol_colmap(rgbind, rgbcol, nintcol){
%!%+
%\function{rgb_interpol_colmap}
%\synopsis{interpolate between multiple rgb colors}
%\usage{col=rgb_interpol_colmap(rgbind, rgbcol, nintcol)}
%\description
%This function builds a color array by interpolating between
%multiple colors. The resulting array has nintcol colors.
%In this array, the colors rgbcol[ii] will be placed at
%col[rgbind[ii]].
%The interpolation between the individual colrs is linear.
%The input color indices rgbind[*] have to be sorted in
%ascending order.
%The result can be assigned as a color map directly using
% png_add_colormap.
%\seealso{mix_rgb_colors}
%!%-

  % check input values for consistency
  
  variable ncol=length(rgbind);
  if(ncol!=length(rgbcol)){
    vmessage("Number of color indices must be equal to number of colors.");
    return NULL;
  }
  if(rgbind[0]!=0){
    vmessage("First color index must be 0.");
  }
  if(rgbind[ncol-1]!=nintcol-1){
    vmessage("Last color index must be nintcol-1.");
  }

  % initialize variables
  
  variable col=Integer_Type[nintcol];

  variable ind, ii;

  ind=0;

  % build color array
  for(ii=0; ii<nintcol; ii++){
    if(ii>rgbind[ind+1]){
      ind++;
    }
    variable fraction=1.*(rgbind[ind+1]-ii)/(1.*(rgbind[ind+1]-rgbind[ind]));
    col[ii]=mix_rgb_colors(rgbcol[ind], rgbcol[ind+1], fraction);
  }

  return col;
}

