define EpochofJD()
%!%+
%\function{EpochofJD}
%\synopsis{Returns the Julian or Besselian epoch of a (M)JD}
%\usage{epoch=EpochofJD(jd;qualifiers)}
%\qualifiers{
%\qualifier{mjd}{argument is a modified julian date, not a JD}
%\qualifier{besselian}{return the Besselian epoch}
%\qualifier{julian}{return the Julian epoch (the default)}
%}
%\description
%   This function converts a (modified) julian date into the corresponding
%   Julian or Besselian epoch (e.g., J2000, B1950.0 etc.) using the formulae
%   given by Lieske (1979, A&A 73, 282) for Besselian dates and the standard
%   definition of the Julian Date. 
%
%   If high precision is relevant, note that JD is assumed to be in TT,
%   note that the epoch will slowly drift with respect to Gregorian year
%   fractions such as those calculated by jd2year, but contrary to that
%   function the Julian/Besselian epoch linearly maps to TT.
%
%   This routine is array safe.
%
%\seealso{JDofEpoch,jd2year}
%!%-
{
    variable jd;

    switch(_NARGS)
    { case 1: jd=(); }
    { help(_function_name());return;}

    % Lieske (1979, A&A 73, 282)
    % Lieske: B = 1900.0 + (Julian date-2415020.31352) / 365.242198781
    %J = 2000.0 + (Julian date-2451545.0)/365.25 .
    
    if(qualifier_exists("besselian")) {
	if (qualifier_exists("mjd")) {
	    return 1900.+(jd-15019.81352)/365.242198781; 
	} else {
	    return 1900.+(jd-2415020.31352)/365.242198781;
	}
    }

    % Julian epoch
    if (qualifier_exists("mjd")) {
	return 2000.0+(jd-51544.5)/365.25;
    }
    return 2000.0+(jd-2451545.0)/365.25; 
}

