define tai2tt()
%!%+
%\function{tai2tt}
%\synopsis{Convert a (M)JD in International Atomic Time into Terrestrial Time (TT, also known as TDT or ET)}
%\usage{tt=tai2tt(JD)}
%\description
%This routine converts a Julian Date that is given in International Atomic
%Time (TAI) into Terrestrial Time, which is roughly corresponding to
%Terrestrial Dynamic Time or Ephemeris Time. This is done by
%adding 32.184s to the TT. This routine is array safe.
%
%\qualifiers{
%\qualifier{mjd}{The argument is given in MJD, not in JD.}
%\qualifier{deltat}{Return the TT-TAI in seconds, rather than the corrected (M)JD.}
%}
%\seealso{utc2tai,tai2utc,tt2tai,tt2tdb}
%!%-
{
    variable JD;
    switch(_NARGS)
    {
	case 1: JD=();
    }
    {
	help(_function_name()); return;
    }

    variable diff=32.184;

    if (qualifier_exists("deltat")) {
	if (typeof(JD)==Array_Type) {
	    return diff+Double_Type[length(JD)];
	}
	return diff;
    }
    return JD+diff/86400.0;
}
